Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: runtime/vm/stub_code_ia32.cc

Issue 14925005: Remove stack_frame_<arch>.cc files. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/stub_code_arm.cc ('k') | runtime/vm/stub_code_mips.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code_ia32.cc
===================================================================
--- runtime/vm/stub_code_ia32.cc (revision 22469)
+++ runtime/vm/stub_code_ia32.cc (working copy)
@@ -14,6 +14,7 @@
#include "vm/object_store.h"
#include "vm/resolver.h"
#include "vm/scavenger.h"
+#include "vm/stack_frame.h"
#include "vm/stub_code.h"
@@ -741,8 +742,9 @@
// Save the top exit frame info. Use EDX as a temporary register.
// StackFrameIterator reads the top exit frame info saved in this frame.
- // The constant kExitLinkOffsetInEntryFrame must be kept in sync with the
- // code below: kExitLinkOffsetInEntryFrame = -4 * kWordSize.
+ // The constant kExitLinkSlotFromEntryFp must be kept in sync with the
+ // code below.
+ ASSERT(kExitLinkSlotFromEntryFp == -4);
__ movl(EDX, Address(EDI, Isolate::top_exit_frame_info_offset()));
__ pushl(EDX);
__ movl(Address(EDI, Isolate::top_exit_frame_info_offset()), Immediate(0));
@@ -750,10 +752,11 @@
// Save the old Context pointer. Use ECX as a temporary register.
// Note that VisitObjectPointers will find this saved Context pointer during
// GC marking, since it traverses any information between SP and
- // FP - kExitLinkOffsetInEntryFrame.
+ // FP - kExitLinkSlotFromEntryFp.
// EntryFrame::SavedContext reads the context saved in this frame.
- // The constant kSavedContextOffsetInEntryFrame must be kept in sync with
- // the code below: kSavedContextOffsetInEntryFrame = -5 * kWordSize.
+ // The constant kSavedContextSlotFromEntryFp must be kept in sync with
+ // the code below.
+ ASSERT(kSavedContextSlotFromEntryFp == -5);
__ movl(ECX, Address(EDI, Isolate::top_context_offset()));
__ pushl(ECX);
« no previous file with comments | « runtime/vm/stub_code_arm.cc ('k') | runtime/vm/stub_code_mips.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698